#ifdef GL_ES
precision highp float;
#endif

uniform lowp vec4 fColor;
uniform lowp sampler2D fTexture;
uniform mediump vec4 fTextureInfo;
//uniform mediump float fStrength;
uniform mediump float fResolution;
uniform mediump float fTime;
uniform mediump vec4 fTexelSize;
varying highp vec2 fTexCoord;

//uniform float     iTime=60.0;                 // shader playback time (in seconds)


//2D (returns 0 - 1)
float random2d(vec2 n) { 
    return fract(sin(dot(n, vec2(12.9898, 4.1414))) * 43758.5453);
}

float randomRange (in vec2 seed, in float min, in float max) {
		return min + random2d(seed) * (max - min);
}

// return 1 if v inside 1d range
float insideRange(float v, float bottom, float top) {
   return step(bottom, v) - step(top, v);
}



void main()
{
  if (fResolution==64.0) {gl_FragColor=texture2D(fTexture,fTexCoord); return;}   

	//inputs
	//float AMT = 1.0-fResolution/128.0; //0 - 1 glitch amount
	//float AMT = 0.25-fResolution/512.0; //0 - 0.25 glitch amount
	float AMT = 0.25-fResolution/256.0; //0 - 0.25 glitch amount
//	float SPEED = 0.5; //0 - 1 speed
  
 //float time = floor(fTime * SPEED * 60.0); 
 float time = fTime; 
  
  
	//vec2 uv = fTexCoord.xy / fResolution.xy;
  vec2 uv=fTexCoord.xy;
    //copy orig
    
    vec4 outCol = texture2D(fTexture, uv).rgba;
    
    //randomly offset slices horizontally
    float maxOffset = AMT/2.0;
    for (float i = 0.0; i < 10.0 * AMT; i += 1.0) {
        float sliceY = random2d(vec2(time , 2345.0 + float(i)));
        float sliceH = random2d(vec2(time , 9035.0 + float(i))) * 0.25;
        float hOffset = randomRange(vec2(time , 9625.0 + float(i)), -maxOffset, maxOffset);
        vec2 uvOff = uv;
        uvOff.x += hOffset;
        if (insideRange(uv.y, sliceY, fract(sliceY+sliceH)) == 1.0 ){
        	outCol = texture2D(fTexture, uvOff).rgba;
        }
    }
    
    //do slight offset on one entire channel
    float maxColOffset = AMT/6.0;
    float rnd = random2d(vec2(time , 9545.0));
    vec2 colOffset = vec2(randomRange(vec2(time , 9545.0),-maxColOffset,maxColOffset), 
                       randomRange(vec2(time , 7205.0),-maxColOffset,maxColOffset));
    if (rnd < 0.33){
        outCol.r = texture2D(fTexture, uv + colOffset).r;
        
    }else if (rnd < 0.66){
        outCol.g = texture2D(fTexture, uv + colOffset).g;
        
    } else{
        outCol.b = texture2D(fTexture, uv + colOffset).b;  
    }
       
	//gl_FragColor = vec4(outCol,1.0);
  outCol.a = texture2D(fTexture, uv + colOffset).a;
  gl_FragColor = vec4(outCol);
}